@@ -17,6 +17,18 @@ css_color = """
   align-self: center;
 }}
 
+.switch-container{{
+  float: right;
+  display: flex;
+  padding-top: 10px;
+}}
+
+.switch-container .switch-description{{
+  margin-top: 6px;
+  padding-right: 8px;
+  
+}}
+
 .switch input {{
   opacity: 0;
   width: 0;
@@ -66,5 +78,13 @@ input:checked + .slider:before {{
   border-radius: 50%;
 }}
 
+.text-column {{
+  overflow-wrap: break-word;
+}}
+
+.color-mode-container {{
+  float: right;
+}}
+
 </style>
 """
