@@ -1,6 +1,6 @@
 gold_corpus = """
 <div class="col-md-6">
     <h2>Gold</h2>
-    <p>{gold_html}</p>
+    <p class="text-column">{gold_html}</p>
 </div>
 """
