@@ -1,6 +1,6 @@
 predicted_corpus = """
 <div class="col-md-6">
     <h2>Predicted</h2>
-    <p>{predicted_html}</p>
+    <p class="text-column">{predicted_html}</p>
 </div>
 """
